@@ -1,11 +1,5 @@
 context("  Filter on")
 
-test_that("An unnamed value results in an error.", {
-    expect_error({
-        DT %>% start_expr %>% filter_on("foo") %>% end_expr
-    })
-})
-
 test_that("The filter_on verb works as expected.", {
     ans <- DT %>% start_expr %>% filter_on(cyl = 6, am = 0) %>% end_expr
     expect_identical(ans, DT[.(6, 0), on = c("cyl", "am")])
@@ -16,6 +10,20 @@ test_that("The filter_on verb works as expected.", {
     ans <- DT %>% start_expr %>% filter_on(cyl = 6, am = 0, mult = "last") %>% end_expr
     expect_identical(ans, DT[.(6, 0), on = c("cyl", "am"), mult = "last"])
 
+    # ----------------------------------------------------------------------------------------------
+
+    expected <- data.table::setkey(data.table::copy(DT), cyl, am)[.(6, 0)]
+
+    ans <- DT %>%
+        data.table::copy(.) %>%
+        data.table::setkey(cyl, am) %>%
+        start_expr %>% filter_on(cyl = 6, 0) %>%
+        end_expr
+
+    expect_identical(ans, expected)
+
+    # ----------------------------------------------------------------------------------------------
+
     ans <- DT %>% start_expr %>% filter_on(cyl = 10) %>% end_expr
     expect_identical(nrow(ans), 1L)
     expect_true(any(sapply(ans, is.na)))
@@ -51,3 +59,19 @@ test_that("The filter_on verb works for several values per key.", {
 
     expect_identical(ans, expected)
 })
+
+test_that("The filter_on verb works when which = TRUE.", {
+    expected <- data.table::copy(DT)[.(1, 0), on = c("vs", "am"), which = TRUE]
+    ans <- DT %>% start_expr %>% filter_on(vs = 1, am = 0, which = TRUE) %>% end_expr(.by_ref = FALSE)
+    expect_identical(ans, expected)
+})
+
+test_that("Eager filter_on works.", {
+    expected <- data.table::copy(DT)[.(1, 0), on = c("vs", "am"), which = TRUE]
+    ans <- data.table::copy(DT) %>% filter_on(vs = 1, am = 0, which = TRUE)
+    expect_identical(ans, expected)
+
+    expected <- data.table::copy(DT)[.(1, 0), flag := TRUE, on = c("vs", "am")]
+    ans <- data.table::copy(DT) %>% filter_on(vs = 1, am = 0, .expr = TRUE) %>% mutate(flag = TRUE)
+    expect_identical(ans, expected)
+})
