@@ -155,15 +155,18 @@ test_that("Eager right_join works.", {
 })
 
 test_that("right_join can delegate to data.frame method when necessary.", {
-    .expr <- rlang::expr((function() {
-        local_rhs <- data.table::as.data.table(!!rhs)
-        right_join(data.table::as.data.table(!!lhs), local_rhs, by = "x")
-    })())
+    .enclos <- rlang::env(asNamespace("rex"),
+                          lhs = data.table::copy(lhs),
+                          rhs = data.table::copy(rhs))
 
-    expect_warning(ans <- eval(.expr, envir = asNamespace("rex")), "table.express")
+    .fn <- rlang::set_env(new_env = .enclos, function() {
+        right_join(lhs, rhs, by = "x")
+    })
+
+    expect_warning(ans <- .fn(), "table.express")
     expect_equal(ans, dplyr:::right_join.data.frame(lhs, rhs, "x"))
 
-    .expr <- rlang::expr(right_join(data.table::as.data.table(!!lhs), data.table::as.data.table(!!rhs), x))
+    .expr <- substitute(right_join(data.table::as.data.table(lhs), data.table::as.data.table(rhs), x), .enclos)
     ans_from_workaround <- eval(.expr, envir = asNamespace("rex"))
     expect_equal(ans_from_workaround, right_join(lhs, rhs, x))
 })
